{
  pkgs,
  lib,
  ...
}: {
  imports = [
    ./hardware-configuration.nix
    ./cachix.nix
  ];

  boot.kernelPackages = pkgs.linuxKernel.packages.linux_hardened;
  boot.kernelParams = ["resume_offset=1560576"];
  boot.resumeDevice = "/dev/disk/by-uuid/3b4660ec-45c5-47ca-9418-1667c373d4b2";
  powerManagement.enable = true;
  swapDevices = [
    {
      device = "/var/lib/swapfile";
      size = 4 * 1024;
    }
  ];

  boot.loader = {
    limine = {
      enable = true;
      efiSupport = true;
    };
    grub = {
      enable = false;
      devices = ["nodev"];
      useOSProber = true;
      efiSupport = true;
    };
    efi.canTouchEfiVariables = true;
    timeout = lib.mkDefault 2;
  };

  services.displayManager = {
    enable = true;
    ly.enable = true;
    defaultSession = "none+xmonad";
  };

  programs.niri.enable = true;
  services.libinput.enable = true;
  services.xserver = {
    enable = true;
    windowManager.xmonad = {
      enable = true;
      enableContribAndExtras = true;
    };
  };

  networking = {
    hostName = "nixos";
    networkmanager.enable = true;
    dhcpcd.enable = false;
    firewall.enable = true;
  };

  time.timeZone = "America/New_York";

  i18n.defaultLocale = "en_US.UTF-8";

  users.users.mtgmonkey = {
    isNormalUser = true;
    description = "mtgmonkey";
    extraGroups = ["networkmanager" "wheel"];
  };

  users.users.test = {
    isNormalUser = true;
    description = "test";
    extraGroups = ["networkmanager" "wheel"];
  };

  nix.settings.experimental-features = ["nix-command" "flakes"];

  system.stateVersion = "25.11";
}
